@@ -7,7 +7,7 @@ use Role::Tiny ();
 use Scalar::Util ();
 use Class::Method::Modifiers ();
 
-our $VERSION = '1.14'; # VERSION
+our $VERSION = '1.15'; # VERSION
 
 my $store;
 
@@ -29,7 +29,6 @@ sub import {
             use Class::Method::Modifiers;
         };
     };
-    die $@ if ($@);
 
     exact->monkey_patch( $caller, $_, \&$_ ) for ( qw( has class_has with ) );
 }
@@ -230,9 +229,17 @@ sub ____role_attrs {
 sub with {
     my $caller = scalar(caller);
     push( @{ $store->{roles}->{$caller} }, @_ );
-    my $result = Role::Tiny->apply_roles_to_package( $caller, @_ );
+
+    try {
+        Role::Tiny->apply_roles_to_package( $caller, $_ ) for @_;
+    }
+    catch ($e) {
+        $e =~ s/\s+at\s.+\sline\s\d+\.\s*$//g;
+        croak $e;
+    }
+
     ____role_attrs( $caller, [@_] );
-    return $result;
+    return;
 }
 
 sub with_roles {
@@ -270,7 +277,7 @@ exact::class - Simple class interface extension for exact
 
 =head1 VERSION
 
-version 1.14
+version 1.15
 
 =for markdown [![test](https://github.com/gryphonshafer/exact-class/workflows/test/badge.svg)](https://github.com/gryphonshafer/exact-class/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/exact-class/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/exact-class)
